==> odoo12_addon_stock_operating_unit-12.0.1.3.0.99.dev1-py3-none-any.whl: odoo/addons/stock_operating_unit/models/stock_picking.py <==
# © 2019 Eficent Business and IT Consulting Services S.L.
# © 2019 Serpent Consulting Services Pvt. Ltd.
# License LGPL-3.0 or later (https://www.gnu.org/licenses/lgpl.html).
from odoo import _, api, fields, models
from odoo.exceptions import UserError


class StockPicking(models.Model):
    _inherit = 'stock.picking'

    operating_unit_id = fields.Many2one(
        'operating.unit',
        'Requesting Operating Unit',
        readonly=True,
        states={'draft': [('readonly', False)]})

    @api.onchange('picking_type_id', 'location_id')
    def onchange_operating_unit(self):
        unit = False
        if self.picking_type_id:
            unit = self.picking_type_id.warehouse_id.operating_unit_id
        if not unit:
            unit = self.location_id and self.location_id.operating_unit_id
        self.operating_unit_id = unit

    @api.multi
    @api.constrains('operating_unit_id', 'company_id')
    def _check_company_operating_unit(self):
        for rec in self:
            if (rec.company_id and rec.operating_unit_id and
                    rec.company_id != rec.operating_unit_id.company_id):
                raise UserError(_(
                    'Configuration error. The Company in the Stock Picking '
                    'and in the Operating Unit must be the same.'))

    @api.multi
    @api.constrains('operating_unit_id', 'picking_type_id')
    def _check_picking_type_operating_unit(self):
        for rec in self:
            warehouse = rec.picking_type_id.warehouse_id
            if (warehouse.operating_unit_id and
                    rec.picking_type_id and rec.operating_unit_id and
                    warehouse.operating_unit_id != rec.operating_unit_id):
                raise UserError(_(
                    'Configuration error. The Operating Unit of the picking '
                    'must be the same as that of the warehouse of the '
                    'Picking Type.'))

==> odoo12_addon_stock_operating_unit-12.0.2.0.0.99.dev10-py3-none-any.whl: odoo/addons/stock_operating_unit/models/stock_picking.py <==
# © 2019 Eficent Business and IT Consulting Services S.L.
# © 2019 Serpent Consulting Services Pvt. Ltd.
# License LGPL-3.0 or later (https://www.gnu.org/licenses/lgpl.html).
from odoo import _, api, fields, models
from odoo.exceptions import UserError


class StockPicking(models.Model):
    _inherit = 'stock.picking'

    operating_unit_id = fields.Many2one(
        'operating.unit',
        'Requesting Operating Unit',
        readonly=True,
        states={'draft': [('readonly', False)]})

    @api.onchange('picking_type_id', 'location_id')
    def onchange_operating_unit(self):
        unit = False
        if self.picking_type_id:
            unit = self.picking_type_id.warehouse_id.operating_unit_id
        if not unit:
            if self.location_id:
                if self.location_id.operating_unit_id:
                    unit = self.location_id.operating_unit_id

        self.operating_unit_id = unit

    @api.multi
    @api.constrains('operating_unit_id', 'company_id')
    def _check_company_operating_unit(self):
        for rec in self:
            if (rec.company_id and rec.operating_unit_id and
                    rec.company_id != rec.operating_unit_id.company_id):
                raise UserError(_(
                    'Configuration error. The Company in the Stock Picking '
                    'and in the Operating Unit must be the same.'))

    @api.multi
    @api.constrains('operating_unit_id', 'picking_type_id')
    def _check_picking_type_operating_unit(self):
        for rec in self:
            warehouse = rec.picking_type_id.warehouse_id
            if (warehouse.operating_unit_id and
                    rec.picking_type_id and rec.operating_unit_id and
                    warehouse.operating_unit_id != rec.operating_unit_id):
                raise UserError(_(
                    'Configuration error. The Operating Unit of the picking '
                    'must be the same as that of the warehouse of the '
                    'Picking Type.'))
